==> haskell-mime-mail-0.4.14-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-mail
version: 0.4.14
id: mime-mail-0.4.14-JaBHeTt9YeHCqeLIBEWjHA
key: mime-mail-0.4.14-JaBHeTt9YeHCqeLIBEWjHA
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
homepage: http://github.com/snoyberg/mime-mail
synopsis: Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.
category: Email
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Mail.Mime
abi: 3c77ac0b13ff222b21a7d4791d07a526
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mime-mail-0.4.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/mime-mail-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mime-mail-0.4.14
hs-libraries: HSmime-mail-0.4.14-JaBHeTt9YeHCqeLIBEWjHA
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    process-1.6.1.0 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH bytestring-0.10.8.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj filepath-1.4.1.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=9a0562647033c21b2abf88c991a65d08
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
haddock-interfaces: /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html: /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.4.14-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-mail
version: 0.4.14
id: mime-mail-0.4.14-KGlbf89gNTxH6eE68umfn1
key: mime-mail-0.4.14-KGlbf89gNTxH6eE68umfn1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
homepage: http://github.com/snoyberg/mime-mail
synopsis: Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.
category: Email
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Mail.Mime
abi: acf4bed4407114ebd700da3cf442591d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mime-mail-0.4.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/mime-mail-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mime-mail-0.4.14
hs-libraries: HSmime-mail-0.4.14-KGlbf89gNTxH6eE68umfn1
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    process-1.6.1.0 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj filepath-1.4.1.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
haddock-interfaces: /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html: /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
